==> tencentcloud-sdk-java-3.1.87-sources.jar: com/tencentcloudapi/tiems/v20190416/models/DeleteRuntimeRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tiems.v20190416.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteRuntimeRequest extends AbstractModel{

    /**
    * 要删除的Runtime名
    */
    @SerializedName("Runtime")
    @Expose
    private String Runtime;

    /**
     * Get 要删除的Runtime名 
     * @return Runtime 要删除的Runtime名
     */
    public String getRuntime() {
        return this.Runtime;
    }

    /**
     * Set 要删除的Runtime名
     * @param Runtime 要删除的Runtime名
     */
    public void setRuntime(String Runtime) {
        this.Runtime = Runtime;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Runtime", this.Runtime);

    }
}

==> tencentcloud-sdk-java-3.1.693-sources.jar: com/tencentcloudapi/tiems/v20190416/models/DeleteRuntimeRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tiems.v20190416.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteRuntimeRequest extends AbstractModel{

    /**
    * 要删除的Runtime名
    */
    @SerializedName("Runtime")
    @Expose
    private String Runtime;

    /**
     * Get 要删除的Runtime名 
     * @return Runtime 要删除的Runtime名
     */
    public String getRuntime() {
        return this.Runtime;
    }

    /**
     * Set 要删除的Runtime名
     * @param Runtime 要删除的Runtime名
     */
    public void setRuntime(String Runtime) {
        this.Runtime = Runtime;
    }

    public DeleteRuntimeRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DeleteRuntimeRequest(DeleteRuntimeRequest source) {
        if (source.Runtime != null) {
            this.Runtime = new String(source.Runtime);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Runtime", this.Runtime);

    }
}
